@@ -376,6 +376,25 @@ def stripQuotes(string):
     return string
 
 
+def reverse_sanitize_quotes(string):
+    orig_list = False
+    if isinstance(string, (list)):
+        orig_list = True
+    if isinstance(string, (str)):
+        string = [string]
+
+    new_list = []
+    for item in string:
+        item = item.replace("&apos_", "'")
+        item = item.replace("&quot_", '"')
+        new_list.append(item)
+
+    if len(new_list) == 1 and orig_list is False:
+        return new_list[0]
+
+    return new_list
+
+
 def sanitize_quotes(string):
     orig_list = False
     if isinstance(string, (list)):
